@@ -11,19 +11,19 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"10.6.5-MariaDB"
-#define MYSQL_BASE_VERSION		"mysqld-10.6"
-#define MARIADB_BASE_VERSION		"mariadb-10.6"
-#define MARIADBD_BASE_VERSION		"mariadbd-10.6"
+#define MYSQL_SERVER_VERSION		"10.7.1-MariaDB"
+#define MYSQL_BASE_VERSION		"mysqld-10.7"
+#define MARIADB_BASE_VERSION		"mariadb-10.7"
+#define MARIADBD_BASE_VERSION		"mariadbd-10.7"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		100605
+#define MYSQL_VERSION_ID		100701
 #define MARIADB_PORT                    3306
 #define MYSQL_PORT_DEFAULT		0
 #define MARIADB_UNIX_ADDR               "/run/mysqld/mysqld.sock"
 #define MYSQL_CONFIG_NAME		"my"
 #define MYSQL_COMPILATION_COMMENT	"Source distribution"
-#define SERVER_MATURITY_LEVEL           MariaDB_PLUGIN_MATURITY_STABLE
+#define SERVER_MATURITY_LEVEL           MariaDB_PLUGIN_MATURITY_GAMMA
 
 #define MYSQL_PORT                      MARIADB_PORT
 #define MYSQL_UNIX_ADDR                 MARIADB_UNIX_ADDR
